@@ -25,7 +25,11 @@
 */
 
 
+#if defined(SDL_FRAMEWORK) || defined(NO_SDL_CONFIG)
+#include <SDL/SDL.h>
+#else
 #include "SDL.h"
+#endif
 
 #ifndef	SDL_INIT_CDROM
 
