@@ -245,6 +245,8 @@ extern	cvar_t	cl_autofire;
 extern	cvar_t	cl_shownet;
 extern	cvar_t	cl_nolerp;
 
+extern	cvar_t	cfg_unbindall;
+
 extern	cvar_t	cl_pitchdriftspeed;
 extern	cvar_t	lookspring;
 extern	cvar_t	lookstrafe;
@@ -319,9 +321,6 @@ void CL_UpdateTEnts (void);
 
 void CL_ClearState (void);
 
-float CL_KeyState (kbutton_t *key);
-const char *Key_KeynumToString (int keynum);
-
 //
 // cl_demo.c
 //
