@@ -655,7 +655,7 @@ void Mod_LoadLighting (lump_t *l)
 		if (path_id < loadmodel->path_id)
 		{
 			Hunk_FreeToLowMark(mark);
-			Con_Printf("ignored %s from a gamedir with lower priority\n", litfilename);
+			Con_DPrintf("ignored %s from a gamedir with lower priority\n", litfilename);
 		}
 		else
 		if (data[0] == 'Q' && data[1] == 'L' && data[2] == 'I' && data[3] == 'T')
@@ -741,7 +741,7 @@ void Mod_LoadEntities (lump_t *l)
 		if (path_id < loadmodel->path_id)
 		{
 			Hunk_FreeToLowMark(mark);
-			Con_Printf("ignored %s from a gamedir with lower priority\n", entfilename);
+			Con_DPrintf("ignored %s from a gamedir with lower priority\n", entfilename);
 		}
 		else
 		{
@@ -841,8 +841,11 @@ void Mod_LoadTexinfo (lump_t *l)
 
 	for ( i=0 ; i<count ; i++, in++, out++)
 	{
-		for (j=0 ; j<8 ; j++)
+		for (j=0 ; j<4 ; j++)
+		{
 			out->vecs[0][j] = LittleFloat (in->vecs[0][j]);
+			out->vecs[1][j] = LittleFloat (in->vecs[1][j]);
+		}
 		len1 = VectorLength (out->vecs[0]);
 		len2 = VectorLength (out->vecs[1]);
 		len1 = (len1 + len2)/2;
