@@ -90,6 +90,7 @@ cvar_t		scr_clock = {"scr_clock", "0", CVAR_NONE};
 
 cvar_t		scr_viewsize = {"viewsize","100", CVAR_ARCHIVE};
 cvar_t		scr_fov = {"fov","90",CVAR_NONE};	// 10 - 170
+cvar_t		scr_fov_adapt = {"fov_adapt","1",CVAR_ARCHIVE};
 cvar_t		scr_conspeed = {"scr_conspeed","500",CVAR_ARCHIVE};
 cvar_t		scr_centertime = {"scr_centertime","2",CVAR_NONE};
 cvar_t		scr_showram = {"showram","1",CVAR_NONE};
@@ -227,6 +228,29 @@ void SCR_CheckDrawCenterString (void)
 
 //=============================================================================
 
+/*
+====================
+AdaptFovx
+Adapt a 4:3 horizontal FOV to the current screen size using the "Hor+" scaling:
+2.0 * atan(width / height * 3.0 / 4.0 * tan(fov_x / 2.0))
+====================
+*/
+float AdaptFovx (float fov_x, float width, float height)
+{
+	float	a, x;
+
+	if (fov_x < 1 || fov_x > 179)
+		Sys_Error ("Bad fov: %f", fov_x);
+
+	if (!scr_fov_adapt.value)
+		return fov_x;
+	if ((x = height / width) == 0.75)
+		return fov_x;
+	a = atan(0.75 / x * tan(fov_x / 360 * M_PI));
+	a = a * 360 / M_PI;
+	return a;
+}
+
 /*
 ====================
 CalcFovy
@@ -234,15 +258,15 @@ CalcFovy
 */
 float CalcFovy (float fov_x, float width, float height)
 {
-    float   a, x;
+	float	a, x;
 
-    if (fov_x < 1 || fov_x > 179)
-            Sys_Error ("Bad fov: %f", fov_x);
+	if (fov_x < 1 || fov_x > 179)
+		Sys_Error ("Bad fov: %f", fov_x);
 
-    x = width/tan(fov_x/360*M_PI);
-    a = atan (height/x);
-    a = a*360/M_PI;
-    return a;
+	x = width / tan(fov_x / 360 * M_PI);
+	a = atan(height / x);
+	a = a * 360 / M_PI;
+	return a;
 }
 
 /*
@@ -297,7 +321,7 @@ static void SCR_CalcRefdef (void)
 	r_refdef.vrect.y = (glheight - sb_lines - r_refdef.vrect.height)/2;
 	//johnfitz
 
-	r_refdef.fov_x = scr_fov.value;
+	r_refdef.fov_x = AdaptFovx(scr_fov.value, r_refdef.vrect.width, r_refdef.vrect.height);
 	r_refdef.fov_y = CalcFovy (r_refdef.fov_x, r_refdef.vrect.width, r_refdef.vrect.height);
 
 	scr_vrect = r_refdef.vrect;
@@ -382,8 +406,10 @@ void SCR_Init (void)
 	Cvar_RegisterVariable (&scr_clock);
 	//johnfitz
 	Cvar_SetCallback (&scr_fov, SCR_Callback_refdef);
+	Cvar_SetCallback (&scr_fov_adapt, SCR_Callback_refdef);
 	Cvar_SetCallback (&scr_viewsize, SCR_Callback_refdef);
 	Cvar_RegisterVariable (&scr_fov);
+	Cvar_RegisterVariable (&scr_fov_adapt);
 	Cvar_RegisterVariable (&scr_viewsize);
 	Cvar_RegisterVariable (&scr_conspeed);
 	Cvar_RegisterVariable (&scr_showram);
@@ -918,7 +944,7 @@ SCR_TileClear -- johnfitz -- modified to use glwidth/glheight instead of vid.wid
 */
 void SCR_TileClear (void)
 {
-	if (scr_tileclear_updates >= vid.numpages && !gl_clear.value && !isIntelVideo) //intel video workarounds from Baker
+	if (scr_tileclear_updates >= vid.numpages && !gl_clear.value)
 		return;
 	scr_tileclear_updates++;
 
@@ -1003,7 +1029,10 @@ void SCR_UpdateScreen (void)
 
 	if (scr_drawdialog) //new game confirm
 	{
-		Sbar_Draw ();
+		if (con_forcedup)
+			Draw_ConsoleBackground ();
+		else
+			Sbar_Draw ();
 		Draw_FadeScreen ();
 		SCR_DrawNotifyString ();
 	}
