@@ -23,7 +23,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 extern cvar_t r_drawflat;
 
-cvar_t r_oldwater = {"r_oldwater", "1", CVAR_NONE};
+cvar_t r_oldwater = {"r_oldwater", "1", CVAR_ARCHIVE};
 cvar_t r_waterquality = {"r_waterquality", "8", CVAR_NONE};
 cvar_t r_waterwarp = {"r_waterwarp", "1", CVAR_NONE};
 
@@ -45,7 +45,7 @@ float	turbsin[] =
 //
 //==============================================================================
 
-extern	model_t	*loadmodel;
+extern	qmodel_t	*loadmodel;
 
 msurface_t	*warpface;
 
