@@ -41,7 +41,6 @@ quakeparms_t *host_parms;
 qboolean	host_initialized;		// true if into command execution
 
 double		host_frametime;
-double		host_time;
 double		realtime;				// without any filtering or bounding
 double		oldrealtime;			// last frame run
 
@@ -81,8 +80,6 @@ cvar_t	developer = {"developer","0",CVAR_NONE};
 
 cvar_t	temp1 = {"temp1","0",CVAR_NONE};
 
-cvar_t	cfg_unbindall = {"cfg_unbindall", "1", CVAR_ARCHIVE}; //QuakeSpasm
-
 cvar_t devstats = {"devstats","0",CVAR_NONE}; //johnfitz -- track developer statistics that vary every frame
 
 devstats_t dev_stats, dev_peakstats;
@@ -96,7 +93,6 @@ Max_Edicts_f -- johnfitz
 static void Max_Edicts_f (cvar_t *var)
 {
 	//TODO: clamp it here?
-
 	if (cls.state == ca_connected || sv.active)
 		Con_Printf ("Changes to max_edicts will not take effect until the next time a map is loaded.\n");
 }
@@ -276,11 +272,7 @@ void Host_InitLocal (void)
 
 	Cvar_RegisterVariable (&temp1);
 
-	Cvar_RegisterVariable (&cfg_unbindall); //QuakeSpasm
-
 	Host_FindMaxClients ();
-
-	host_time = 1.0;		// so a think at time 0 won't get called
 }
 
 
@@ -308,8 +300,6 @@ void Host_WriteConfiguration (void)
 
 		VID_SyncCvars (); //johnfitz -- write actual current mode to config file, in case cvars were messed with
 
-		if (cfg_unbindall.value) fprintf (f, "unbindall\n"); //QuakeSpasm -- unbindall before loading stored bindings
-
 		Key_WriteBindings (f);
 		Cvar_WriteVariables (f);
 
@@ -378,12 +368,14 @@ void SV_BroadcastPrintf (const char *fmt, ...)
 	q_vsnprintf (string, sizeof(string), fmt, argptr);
 	va_end (argptr);
 
-	for (i=0 ; i<svs.maxclients ; i++)
+	for (i = 0; i < svs.maxclients; i++)
+	{
 		if (svs.clients[i].active && svs.clients[i].spawned)
 		{
 			MSG_WriteByte (&svs.clients[i].message, svc_print);
 			MSG_WriteString (&svs.clients[i].message, string);
 		}
+	}
 }
 
 /*
@@ -453,7 +445,7 @@ void SV_DropClient (qboolean crash)
 	net_activeconnections--;
 
 // send notification to all clients
-	for (i=0, client = svs.clients ; i<svs.maxclients ; i++, client++)
+	for (i = 0, client = svs.clients; i < svs.maxclients; i++, client++)
 	{
 		if (!client->active)
 			continue;
@@ -528,14 +520,14 @@ void Host_ShutdownServer(qboolean crash)
 	if (count)
 		Con_Printf("Host_ShutdownServer: NET_SendToAll failed for %u clients\n", count);
 
-	for (i=0, host_client = svs.clients ; i<svs.maxclients ; i++, host_client++)
+	for (i = 0, host_client = svs.clients; i < svs.maxclients; i++, host_client++)
 		if (host_client->active)
 			SV_DropClient(crash);
 
 //
 // clear structures
 //
-	memset (&sv, 0, sizeof(sv));
+//	memset (&sv, 0, sizeof(sv)); // ServerSpawn already do this by Host_ClearMemory
 	memset (svs.clients, 0, svs.maxclientslimit*sizeof(client_t));
 }
 
@@ -696,6 +688,7 @@ void _Host_Frame (float time)
 		return;			// don't run too fast, or packets will flood out
 
 // get new key events
+	Key_UpdateForDest ();
 	Sys_SendKeyEvents ();
 
 // allow mice or other external controllers to add commands
@@ -733,13 +726,9 @@ void _Host_Frame (float time)
 	if (!sv.active)
 		CL_SendCmd ();
 
-	host_time += host_frametime;
-
 // fetch results from server
 	if (cls.state == ca_connected)
-	{
 		CL_ReadFromServer ();
-	}
 
 // update video
 	if (host_speeds.value)
@@ -805,7 +794,7 @@ void Host_Frame (float time)
 	timecount = 0;
 	timetotal = 0;
 	c = 0;
-	for (i=0 ; i<svs.maxclients ; i++)
+	for (i = 0; i < svs.maxclients; i++)
 	{
 		if (svs.clients[i].active)
 			c++;
@@ -823,8 +812,7 @@ void Host_Init (void)
 {
 	if (standard_quake)
 		minimum_memory = MINIMUM_MEMORY;
-	else
-		minimum_memory = MINIMUM_MEMORY_LEVELPAK;
+	else	minimum_memory = MINIMUM_MEMORY_LEVELPAK;
 
 	if (COM_CheckParm ("-minmemory"))
 		host_parms->memsize = minimum_memory;
@@ -869,7 +857,7 @@ void Host_Init (void)
 		ExtraMaps_Init (); //johnfitz
 		Modlist_Init (); //johnfitz
 		VID_Init ();
-		IN_Init (); // moved here, SDL inits the input system with the video system -- kristian
+		IN_Init ();
 		TexMgr_Init (); //johnfitz
 		Draw_Init ();
 		SCR_Init ();
@@ -939,7 +927,7 @@ void Host_Shutdown(void)
 		BGM_Shutdown();
 		CDAudio_Shutdown ();
 		S_Shutdown ();
-		IN_Shutdown (); // input is only initialized in Host_Init if we're not dedicated -- kristian
+		IN_Shutdown ();
 		VID_Shutdown();
 	}
 
