@@ -835,7 +835,7 @@ void Host_Map_f (void)
 
 	svs.serverflags = 0;			// haven't completed an episode yet
 	q_strlcpy (name, Cmd_Argv(1), sizeof(name));
-	// remove (any) trailing ".bsp" from mapname S.A.
+	// remove (any) trailing ".bsp" from mapname -- S.A.
 	p = strstr(name, ".bsp");
 	if (p && p[4] == '\0')
 		*p = '\0';
@@ -866,7 +866,6 @@ Goes to a new map, taking all clients along
 void Host_Changelevel_f (void)
 {
 	char	level[MAX_QPATH];
-	int		i; //johnfitz
 
 	if (Cmd_Argc() != 2)
 	{
@@ -881,7 +880,7 @@ void Host_Changelevel_f (void)
 
 	//johnfitz -- check for client having map before anything else
 	q_snprintf (level, sizeof(level), "maps/%s.bsp", Cmd_Argv(1));
-	if (COM_OpenFile (level, &i, NULL) == -1)
+	if (!COM_FileExists(level, NULL))
 		Host_Error ("cannot find map %s", level);
 	//johnfitz
 
@@ -891,6 +890,9 @@ void Host_Changelevel_f (void)
 	SV_SaveSpawnparms ();
 	q_strlcpy (level, Cmd_Argv(1), sizeof(level));
 	SV_SpawnServer (level);
+	// also issue an error if spawn failed -- O.S.
+	if (!sv.active)
+		Host_Error ("cannot run map %s", level);
 }
 
 /*
@@ -909,9 +911,10 @@ void Host_Restart_f (void)
 
 	if (cmd_source != src_command)
 		return;
-	q_strlcpy (mapname, sv.name, sizeof(mapname));	// must copy out, because it gets cleared
-								// in sv_spawnserver
+	q_strlcpy (mapname, sv.name, sizeof(mapname));	// mapname gets cleared in spawnserver
 	SV_SpawnServer (mapname);
+	if (!sv.active)
+		Host_Error ("cannot restart map %s", mapname);
 }
 
 /*
@@ -1294,16 +1297,13 @@ void Host_Say(qboolean teamonly)
 
 	if (cmd_source == src_command)
 	{
-		if (cls.state == ca_dedicated)
-		{
-			fromServer = true;
-			teamonly = false;
-		}
-		else
+		if (cls.state != ca_dedicated)
 		{
 			Cmd_ForwardToServer ();
 			return;
 		}
+		fromServer = true;
+		teamonly = false;
 	}
 
 	if (Cmd_Argc () < 2)
@@ -1618,12 +1618,9 @@ void Host_Spawn_f (void)
 		ent->v.netname = PR_SetEngineString(host_client->name);
 
 		// copy spawn parms out of the client_t
-
 		for (i=0 ; i< NUM_SPAWN_PARMS ; i++)
 			(&pr_global_struct->parm1)[i] = host_client->spawn_parms[i];
-
 		// call the spawn function
-
 		pr_global_struct->time = sv.time;
 		pr_global_struct->self = EDICT_TO_PROG(sv_player);
 		PR_ExecuteProgram (pr_global_struct->ClientConnect);
@@ -1682,7 +1679,6 @@ void Host_Spawn_f (void)
 	MSG_WriteByte (&host_client->message, STAT_MONSTERS);
 	MSG_WriteLong (&host_client->message, pr_global_struct->killed_monsters);
 
-
 //
 // send a fixangle
 // Never send a roll angle, because savegames can catch the server
@@ -1789,10 +1785,10 @@ void Host_Kick_f (void)
 			message = COM_Parse(Cmd_Args());
 			if (byNumber)
 			{
-				message++;							// skip the #
-				while (*message == ' ')				// skip white space
+				message++;			// skip the #
+				while (*message == ' ')		// skip white space
 					message++;
-				message += Q_strlen(Cmd_Argv(2));	// skip the number
+				message += strlen(Cmd_Argv(2));	// skip the number
 			}
 			while (*message && *message == ' ')
 				message++;
