@@ -27,9 +27,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //be sure to free the hunk after using these loading functions
 byte *Image_LoadTGA (FILE *f, int *width, int *height);
 byte *Image_LoadPCX (FILE *f, int *width, int *height);
-byte *Image_LoadImage (char *name, int *width, int *height);
+byte *Image_LoadImage (const char *name, int *width, int *height);
 
-qboolean Image_WriteTGA (char *name, byte *data, int width, int height, int bpp, qboolean upsidedown);
+qboolean Image_WriteTGA (const char *name, byte *data, int width, int height, int bpp, qboolean upsidedown);
 
 #endif	/* __GL_IMAGE_H */
 
