@@ -39,6 +39,9 @@ void IN_MouseMove(int dx, int dy);
 void IN_SendKeyEvents (void);
 // used as a callback for Sys_SendKeyEvents() by some drivers
 
+void IN_UpdateForKeydest (void);
+// do stuff if key_dest changes matter to the keyboard driver
+
 void IN_Move (usercmd_t *cmd);
 // add additional movement on top of the keyboard move cmd
 
