@@ -410,7 +410,7 @@ void Key_Console (int key)
 
 	case 'v':
 	case 'V':
-#if defined(__MACOSX__) || defined(__MACOS__)
+#if defined(PLATFORM_OSX) || defined(PLATFORM_MAC)
 		if (keydown[K_COMMAND]) {	/* Cmd+v paste (Mac-only) */
 			PasteToConsole();
 			return;
@@ -466,50 +466,59 @@ void Key_Console (int key)
 
 //============================================================================
 
-char chat_buffer[MAXCMDLINE];
-qboolean team_message = false;
+qboolean	chat_team = false;
+static char	chat_buffer[MAXCMDLINE];
+static int	chat_bufferlen = 0;
+
+const char *Key_GetChatBuffer (void)
+{
+	return chat_buffer;
+}
+
+int Key_GetChatMsgLen (void)
+{
+	return chat_bufferlen;
+}
+
+void Key_EndChat (void)
+{
+	key_dest = key_game;
+	chat_bufferlen = 0;
+	chat_buffer[0] = 0;
+}
 
 void Key_Message (int key)
 {
-	static int chat_bufferlen = 0;
-
 	if (key == K_ENTER)
 	{
-		if (team_message)
+		if (chat_team)
 			Cbuf_AddText ("say_team \"");
 		else
 			Cbuf_AddText ("say \"");
 		Cbuf_AddText(chat_buffer);
 		Cbuf_AddText("\"\n");
 
-		key_dest = key_game;
-		chat_bufferlen = 0;
-		chat_buffer[0] = 0;
+		Key_EndChat ();
 		return;
 	}
 
 	if (key == K_ESCAPE)
 	{
-		key_dest = key_game;
-		chat_bufferlen = 0;
-		chat_buffer[0] = 0;
+		Key_EndChat ();
 		return;
 	}
 
-	if (key < 32 || key > 127)
-		return;	// non printable
-
 	if (key == K_BACKSPACE)
 	{
 		if (chat_bufferlen)
-		{
-			chat_bufferlen--;
-			chat_buffer[chat_bufferlen] = 0;
-		}
+			chat_buffer[--chat_bufferlen] = 0;
 		return;
 	}
 
-	if (chat_bufferlen == sizeof(chat_buffer)-1)
+	if (key < 32 || key > 127)
+		return; // non printable
+
+	if (chat_bufferlen == sizeof(chat_buffer) - 1)
 		return; // all full
 
 	chat_buffer[chat_bufferlen++] = key;
@@ -712,6 +721,9 @@ void Key_WriteBindings (FILE *f)
 {
 	int	i;
 
+	// unbindall before loading stored bindings:
+	if (cfg_unbindall.value)
+		fprintf (f, "unbindall\n");
 	for (i = 0; i < 256; i++)
 	{
 		if (keybindings[i] && *keybindings[i])
@@ -796,8 +808,7 @@ void Key_Init (void)
 {
 	int	i;
 
-	History_Init ();
-#if 0 /* This section of code is now done in History_Init */
+#if 0 /* moved to History_Init() */
 	for (i = 0; i < 32; i++)
 	{
 		key_lines[i][0] = ']';
@@ -805,6 +816,7 @@ void Key_Init (void)
 	}
 	key_linepos = 1;
 #endif
+	History_Init ();
 
 	key_blinktime = realtime; //johnfitz
 
@@ -1011,7 +1023,6 @@ void Key_Event (int key, qboolean down)
 	}
 }
 
-
 /*
 ===================
 Key_ClearStates
@@ -1028,3 +1039,42 @@ void Key_ClearStates (void)
 	}
 }
 
+/*
+===================
+Key_UpdateForDest
+===================
+*/
+void Key_UpdateForDest (void)
+{
+	static qboolean forced = false;
+
+	if (cls.state == ca_dedicated)
+		return;
+
+	switch (key_dest)
+	{
+	case key_console:
+		if (forced && cls.state == ca_connected)
+		{
+			forced = false;
+			IN_Activate();
+			key_dest = key_game;
+		}
+		break;
+	case key_game:
+		if (cls.state != ca_connected)
+		{
+			forced = true;
+			IN_Deactivate(modestate == MS_WINDOWED);
+			key_dest = key_console;
+			break;
+		}
+	/* fallthrough */
+	default:
+		forced = false;
+		break;
+	}
+
+	IN_UpdateForKeydest ();
+}
+
