@@ -247,7 +247,7 @@ void M_Menu_Main_f (void)
 		m_save_demonum = cls.demonum;
 		cls.demonum = -1;
 	}
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_main;
 	m_entersound = true;
@@ -264,7 +264,7 @@ void M_Main_Draw (void)
 	M_DrawPic ( (320-p->width)/2, 4, p);
 	M_DrawTransPic (72, 32, Draw_CachePic ("gfx/mainmenu.lmp") );
 
-	f = (int)(realtime * 10)%6; //johnfitz -- was host_time
+	f = (int)(realtime * 10)%6;
 
 	M_DrawTransPic (54, 32 + m_main_cursor * 20,Draw_CachePic( va("gfx/menudot%i.lmp", f+1 ) ) );
 }
@@ -334,7 +334,7 @@ int	m_singleplayer_cursor;
 
 void M_Menu_SinglePlayer_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_singleplayer;
 	m_entersound = true;
@@ -351,7 +351,7 @@ void M_SinglePlayer_Draw (void)
 	M_DrawPic ( (320-p->width)/2, 4, p);
 	M_DrawTransPic (72, 32, Draw_CachePic ("gfx/sp_menu.lmp") );
 
-	f = (int)(realtime * 10)%6; //johnfitz -- was host_time
+	f = (int)(realtime * 10)%6;
 
 	M_DrawTransPic (54, 32 + m_singleplayer_cursor * 20,Draw_CachePic( va("gfx/menudot%i.lmp", f+1 ) ) );
 }
@@ -451,7 +451,7 @@ void M_Menu_Load_f (void)
 	m_entersound = true;
 	m_state = m_load;
 
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	M_ScanSaves ();
 }
@@ -468,7 +468,7 @@ void M_Menu_Save_f (void)
 	m_entersound = true;
 	m_state = m_save;
 
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	M_ScanSaves ();
 }
@@ -591,7 +591,7 @@ int	m_multiplayer_cursor;
 
 void M_Menu_MultiPlayer_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_multiplayer;
 	m_entersound = true;
@@ -608,7 +608,7 @@ void M_MultiPlayer_Draw (void)
 	M_DrawPic ( (320-p->width)/2, 4, p);
 	M_DrawTransPic (72, 32, Draw_CachePic ("gfx/mp_menu.lmp") );
 
-	f = (int)(realtime * 10)%6; //johnfitz -- was host_time
+	f = (int)(realtime * 10)%6;
 
 	M_DrawTransPic (54, 32 + m_multiplayer_cursor * 20,Draw_CachePic( va("gfx/menudot%i.lmp", f+1 ) ) );
 
@@ -676,7 +676,7 @@ int		setup_bottom;
 
 void M_Menu_Setup_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_setup;
 	m_entersound = true;
@@ -855,7 +855,7 @@ const char *net_helpMessage [] =
 
 void M_Menu_Net_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_net;
 	m_entersound = true;
@@ -900,7 +900,7 @@ void M_Net_Draw (void)
 	M_Print (f, 120, net_helpMessage[m_net_cursor*4+2]);
 	M_Print (f, 128, net_helpMessage[m_net_cursor*4+3]);
 
-	f = (int)(realtime * 10)%6; //johnfitz -- was host_time
+	f = (int)(realtime * 10)%6;
 	M_DrawTransPic (54, 32 + m_net_cursor * 20,Draw_CachePic( va("gfx/menudot%i.lmp", f+1 ) ) );
 }
 
@@ -972,7 +972,7 @@ int		options_cursor;
 
 void M_Menu_Options_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_options;
 	m_entersound = true;
@@ -1037,6 +1037,8 @@ void M_AdjustSliders (int dir)
 		break;
 
 	case OPT_ALWAYRUN:	// always run
+		if (cl_movespeedkey.value <= 1)
+			Cvar_Set ("cl_movespeedkey", "2.0");
 		if (cl_forwardspeed.value > 200)
 		{
 			Cvar_Set ("cl_forwardspeed", "200");
@@ -1044,8 +1046,8 @@ void M_AdjustSliders (int dir)
 		}
 		else
 		{
-			Cvar_Set ("cl_forwardspeed", "400");
-			Cvar_Set ("cl_backspeed", "400");
+			Cvar_SetValue ("cl_forwardspeed", 200 * cl_movespeedkey.value);
+			Cvar_SetValue ("cl_backspeed", 200 * cl_movespeedkey.value);
 		}
 		break;
 
@@ -1290,7 +1292,7 @@ static int	keys_top;
 
 void M_Menu_Keys_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_keys;
 	m_entersound = true;
@@ -1414,7 +1416,7 @@ void M_Keys_Key (int k)
 		}
 
 		m_keys_bind_grab = false;
-		IN_Deactivate(vid.type == MODE_WINDOWED); // deactivate because we're returning to the menu
+		IN_Deactivate(modestate == MS_WINDOWED); // deactivate because we're returning to the menu
 		return;
 	}
 
@@ -1491,7 +1493,7 @@ int		help_page;
 
 void M_Menu_Help_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_help;
 	m_entersound = true;
@@ -1543,7 +1545,7 @@ void M_Menu_Quit_f (void)
 	if (m_state == m_quit)
 		return;
 	wasInMenus = (key_dest == key_menu);
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_quit_prevstate = m_state;
 	m_state = m_quit;
@@ -1574,7 +1576,7 @@ void M_Quit_Key (int key)
 
 	case 'Y':
 	case 'y':
-		IN_Deactivate(vid.type == MODE_WINDOWED);
+		IN_Deactivate(modestate == MS_WINDOWED);
 		key_dest = key_console;
 		Host_Quit_f ();
 		break;
@@ -1628,7 +1630,7 @@ char	lanConfig_joinname[22];
 
 void M_Menu_LanConfig_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_lanconfig;
 	m_entersound = true;
@@ -1976,7 +1978,7 @@ double m_serverInfoMessageTime;
 
 void M_Menu_GameOptions_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_gameoptions;
 	m_entersound = true;
@@ -2280,7 +2282,7 @@ double		searchCompleteTime;
 
 void M_Menu_Search_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_search;
 	m_entersound = false;
@@ -2341,7 +2343,7 @@ qboolean slist_sorted;
 
 void M_Menu_ServerList_f (void)
 {
-	IN_Deactivate(vid.type == MODE_WINDOWED);
+	IN_Deactivate(modestate == MS_WINDOWED);
 	key_dest = key_menu;
 	m_state = m_slist;
 	m_entersound = true;
