@@ -21,7 +21,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "quakedef.h"
+#if defined(SDL_FRAMEWORK) || defined(NO_SDL_CONFIG)
+#include <SDL/SDL.h>
+#else
 #include "SDL.h"
+#endif
 
 static const Uint8 bmp_bytes[] =
 {
@@ -32,6 +36,7 @@ void PL_SetWindowIcon (void)
 {
 	SDL_RWops	*rwop;
 	SDL_Surface	*icon;
+	Uint32		colorkey;
 
 	/* SDL_RWFromConstMem() requires SDL >= 1.2.7 */
 	rwop = SDL_RWFromConstMem(bmp_bytes, sizeof(bmp_bytes));
@@ -40,6 +45,9 @@ void PL_SetWindowIcon (void)
 	icon = SDL_LoadBMP_RW(rwop, 1);
 	if (icon == NULL)
 		return;
+	/* make pure magenta (#ff00ff) tranparent */
+	colorkey = SDL_MapRGB(icon->format, 255, 0, 255);
+	SDL_SetColorKey(icon, SDL_SRCCOLORKEY, colorkey);
 	SDL_WM_SetIcon(icon, NULL);
 	SDL_FreeSurface(icon);
 }
@@ -48,9 +56,12 @@ void PL_VID_Shutdown (void)
 {
 }
 
+char *PL_GetClipboardData (void)
+{
+	return NULL;
+}
+
 void PL_ErrorDialog (const char *errorMsg)
 {
-// TODO: we can dlopen gtk for an error
-// dialog window. would it be worth it?
 }
 
