@@ -23,13 +23,16 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef _QUAKE_PLATFORM_H
 #define _QUAKE_PLATFORM_H
 
-// platform dependent way to set the window icon
+/* platform dependent way to set the window icon */
 void PL_SetWindowIcon(void);
 
-// platform dependent cleanup
+/* platform dependent cleanup */
 void PL_VID_Shutdown (void);
 
-// show an error dialog
+/* retrieve text from the clipboard (returns Z_Malloc()'ed data) */
+char *PL_GetClipboardData (void);
+
+/* show an error dialog */
 void PL_ErrorDialog(const char *text);
 
 #endif	/* _QUAKE_PLATFORM_H */
