@@ -59,11 +59,11 @@ static char *PF_VarString (int	first)
 		s = q_strlcat(out, G_STRING((OFS_PARM0+i*3)), sizeof(out));
 		if (s >= sizeof(out))
 		{
-			Con_Printf("PF_VarString: overflow (string truncated)\n");
+			Con_Warning("PF_VarString: overflow (string truncated)\n");
 			return out;
 		}
 	}
-	if (s > 255)
+	if (s > 255 && developer.value)
 		Con_Warning("PF_VarString: %i characters exceeds standard limit of 255.\n", (int) s);
 	return out;
 }
@@ -632,13 +632,13 @@ static void PF_sound (void)
 	attenuation = G_FLOAT(OFS_PARM4);
 
 	if (volume < 0 || volume > 255)
-		Sys_Error ("SV_StartSound: volume = %i", volume);
+		Host_Error ("SV_StartSound: volume = %i", volume);
 
 	if (attenuation < 0 || attenuation > 4)
-		Sys_Error ("SV_StartSound: attenuation = %f", attenuation);
+		Host_Error ("SV_StartSound: attenuation = %f", attenuation);
 
 	if (channel < 0 || channel > 7)
-		Sys_Error ("SV_StartSound: channel = %i", channel);
+		Host_Error ("SV_StartSound: channel = %i", channel);
 
 	SV_StartSound (entity, channel, sample, volume, attenuation);
 }
