@@ -24,14 +24,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "quakedef.h"
 
 extern cvar_t gl_fullbrights, r_drawflat, gl_overbright, r_oldwater; //johnfitz
-
 extern cvar_t gl_zfix; // QuakeSpasm z-fighting fix
 
 int		gl_lightmap_format;
 int		lightmap_bytes;
 
-#define	BLOCK_WIDTH		128 //johnfitz -- was 128
-#define	BLOCK_HEIGHT	128 //johnfitz -- was 128
+#define	BLOCK_WIDTH	128
+#define	BLOCK_HEIGHT	128
 
 gltexture_t	*lightmap_textures[MAX_LIGHTMAPS]; //johnfitz -- changed to an array
 
@@ -563,7 +562,6 @@ void R_DrawBrushModel (entity_t *e)
 	//
 	// draw it
 	//
-
 	if (r_drawflat_cheatsafe) //johnfitz
 		glDisable(GL_TEXTURE_2D);
 
@@ -622,7 +620,7 @@ void R_DrawBrushModel_ShowTris (entity_t *e)
 
 	psurf = &clmodel->surfaces[clmodel->firstmodelsurface];
 
-    glPushMatrix ();
+	glPushMatrix ();
 	e->angles[0] = -e->angles[0];	// stupid quake bug
 	R_RotateForEntity (e->origin, e->angles);
 	e->angles[0] = -e->angles[0];	// stupid quake bug
@@ -630,7 +628,6 @@ void R_DrawBrushModel_ShowTris (entity_t *e)
 	//
 	// draw it
 	//
-
 	for (i=0 ; i<clmodel->nummodelsurfaces ; i++, psurf++)
 	{
 		pplane = psurf->plane;
@@ -793,7 +790,6 @@ void BuildSurfaceDisplayList (msurface_t *fa)
 {
 	int			i, lindex, lnumverts;
 	medge_t		*pedges, *r_pedge;
-//	int		vertpage;
 	float		*vec;
 	float		s, t;
 	glpoly_t	*poly;
@@ -801,7 +797,6 @@ void BuildSurfaceDisplayList (msurface_t *fa)
 // reconstruct the polygon
 	pedges = currentmodel->edges;
 	lnumverts = fa->numedges;
-//	vertpage = 0;
 
 	//
 	// draw texture
@@ -857,7 +852,6 @@ void BuildSurfaceDisplayList (msurface_t *fa)
 	//johnfitz -- removed gl_keeptjunctions code
 
 	poly->numverts = lnumverts;
-
 }
 
 /*
@@ -884,18 +878,19 @@ void GL_BuildLightmaps (void)
 		lightmap_textures[i] = NULL;
 	//johnfitz
 
-	gl_lightmap_format = GL_RGB; //johnfitz
+	gl_lightmap_format = GL_RGBA;//FIXME: hardcoded for now!
 
-	//johnfitz -- only support GL_RGB lightmaps
 	switch (gl_lightmap_format)
 	{
-	case GL_RGB:
-		lightmap_bytes = 3;
+	case GL_RGBA:
+		lightmap_bytes = 4;
+		break;
+	case GL_BGRA:
+		lightmap_bytes = 4;
 		break;
 	default:
 		Sys_Error ("GL_BuildLightmaps: bad lightmap format");
 	}
-	//johnfitz
 
 	for (j=1 ; j<MAX_MODELS ; j++)
 	{
@@ -1040,7 +1035,7 @@ Combine and scale multiple lightmaps into the 8.8 format in blocklights
 void R_BuildLightMap (msurface_t *surf, byte *dest, int stride)
 {
 	int			smax, tmax;
-	int			t;
+	int			r,g,b;
 	int			i, j, size;
 	byte		*lightmap;
 	unsigned	scale;
@@ -1089,12 +1084,10 @@ void R_BuildLightMap (msurface_t *surf, byte *dest, int stride)
 
 // bound, invert, and shift
 // store:
-
-	//johnfitz -- only support GL_RGB lightmaps
 	switch (gl_lightmap_format)
 	{
-	case GL_RGB:
-		stride -= smax * 3;
+	case GL_RGBA:
+		stride -= smax * 4;
 		bl = blocklights;
 		for (i=0 ; i<tmax ; i++, dest += stride)
 		{
@@ -1102,23 +1095,52 @@ void R_BuildLightMap (msurface_t *surf, byte *dest, int stride)
 			{
 				if (gl_overbright.value)
 				{
-					t = *bl++ >> 8;if (t > 255) t = 255;*dest++ = t;
-					t = *bl++ >> 8;if (t > 255) t = 255;*dest++ = t;
-					t = *bl++ >> 8;if (t > 255) t = 255;*dest++ = t;
+					r = *bl++ >> 8;
+					g = *bl++ >> 8;
+					b = *bl++ >> 8;
 				}
 				else
 				{
-					t = *bl++ >> 7;if (t > 255) t = 255;*dest++ = t;
-					t = *bl++ >> 7;if (t > 255) t = 255;*dest++ = t;
-					t = *bl++ >> 7;if (t > 255) t = 255;*dest++ = t;
+					r = *bl++ >> 7;
+					g = *bl++ >> 7;
+					b = *bl++ >> 7;
 				}
+				if (r > 255) r = 255; *dest++ = r;
+				if (g > 255) g = 255; *dest++ = g;
+				if (b > 255) b = 255; *dest++ = b;
+				*dest++ = 255;
+			}
+		}
+		break;
+	case GL_BGRA:
+		stride -= smax * 4;
+		bl = blocklights;
+		for (i=0 ; i<tmax ; i++, dest += stride)
+		{
+			for (j=0 ; j<smax ; j++)
+			{
+				if (gl_overbright.value)
+				{
+					r = *bl++ >> 8;
+					g = *bl++ >> 8;
+					b = *bl++ >> 8;
+				}
+				else
+				{
+					r = *bl++ >> 7;
+					g = *bl++ >> 7;
+					b = *bl++ >> 7;
+				}
+				if (b > 255) b = 255; *dest++ = b;
+				if (g > 255) g = 255; *dest++ = g;
+				if (r > 255) r = 255; *dest++ = r;
+				*dest++ = 255;
 			}
 		}
 		break;
 	default:
 		Sys_Error ("R_BuildLightMap: bad lightmap format");
 	}
-	//johnfitz
 }
 
 /*
