@@ -202,8 +202,12 @@ void R_EntityParticles (entity_t *ent)
 
 	if (!avelocities[0][0])
 	{
-		for (i = 0; i < NUMVERTEXNORMALS*3; i++)
-			avelocities[0][i] = (rand() & 255) * 0.01;
+		for (i = 0; i < NUMVERTEXNORMALS; i++)
+		{
+			avelocities[i][0] = (rand() & 255) * 0.01;
+			avelocities[i][1] = (rand() & 255) * 0.01;
+			avelocities[i][2] = (rand() & 255) * 0.01;
+		}
 	}
 
 	for (i = 0; i < NUMVERTEXNORMALS; i++)
@@ -268,9 +272,12 @@ void R_ReadPointFile_f (void)
 	int		r;
 	int		c;
 	particle_t	*p;
-	char	name[MAX_OSPATH];
+	char	name[MAX_QPATH];
 
-	q_snprintf (name, sizeof(name), "maps/%s.pts", sv.name);
+	if (cls.state != ca_connected)
+		return;			// need an active map.
+
+	q_snprintf (name, sizeof(name), "maps/%s.pts", cl.mapname);
 
 	COM_FOpenFile (name, &f, NULL);
 	if (!f)
