@@ -8,7 +8,7 @@
  * functions were adapted from the GPL-licensed libid3tag library, see at
  * http://www.underbit.com/products/mad/.  Adapted to Quake and Hexen II
  * game engines by O.Sezer :
- * Copyright (C) 2010-2011 O.Sezer <sezero@users.sourceforge.net>
+ * Copyright (C) 2010-2012 O.Sezer <sezero@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
  */
 
 #include "quakedef.h"
@@ -499,6 +498,7 @@ static void S_MP3_CodecShutdown (void)
 static snd_stream_t *S_MP3_CodecOpenStream (const char *filename)
 {
 	snd_stream_t *stream;
+	int err;
 
 	stream = S_CodecUtilOpen(filename, &mp3_codec);
 	if (!stream)
@@ -516,10 +516,21 @@ static snd_stream_t *S_MP3_CodecOpenStream (const char *filename)
 	}
 #endif
 
-	if (mp3_startread(stream) == 0)
+	err = mp3_startread(stream);
+	if (err != 0)
+	{
+		Con_Printf("%s is not a valid mp3 file\n", filename);
+	}
+	else if (stream->info.channels != 1 && stream->info.channels != 2)
+	{
+		Con_Printf("Unsupported number of channels %d in %s\n",
+					stream->info.channels, filename);
+	}
+	else
+	{
 		return stream;
+	}
 
-	Con_Printf("%s is not a valid mp3 file\n", filename);
 #if 0 /*defined(CODECS_USE_ZONE)*/
 	Z_Free(stream->priv);
 #else
