@@ -37,10 +37,10 @@
 #include <vorbis/vorbisfile.h>
 #endif
 
-/* The OGG codec can return the samples in a number of different
+/* Vorbis codec can return the samples in a number of different
  * formats, we use the standard signed short format. */
-#define OGG_SAMPLEWIDTH 2
-#define OGG_SIGNED_DATA 1
+#define VORBIS_SAMPLEWIDTH 2
+#define VORBIS_SIGNED_DATA 1
 
 /* CALLBACK FUNCTIONS: */
 
@@ -65,23 +65,24 @@ static const ov_callbacks ovc_qfs =
 
 #define OV_OPEN_CALLBACKS		ov_open_callbacks
 
-static qboolean S_OGG_CodecInitialize (void)
+static qboolean S_VORBIS_CodecInitialize (void)
 {
 	return true;
 }
 
-static void S_OGG_CodecShutdown (void)
+static void S_VORBIS_CodecShutdown (void)
 {
 }
 
-static snd_stream_t *S_OGG_CodecOpenStream (const char *filename)
+static snd_stream_t *S_VORBIS_CodecOpenStream (const char *filename)
 {
 	snd_stream_t *stream;
 	OggVorbis_File *ovFile;
-	vorbis_info *ogg_info;
+	vorbis_info *ovf_info;
+	long numstreams;
 	int res;
 
-	stream = S_CodecUtilOpen(filename, &ogg_codec);
+	stream = S_CodecUtilOpen(filename, &vorbis_codec);
 	if (!stream)
 		return NULL;
 
@@ -98,27 +99,36 @@ static snd_stream_t *S_OGG_CodecOpenStream (const char *filename)
 
 	if (!ov_seekable(ovFile))
 	{
-		Con_Printf("OGG_Open: stream %s not seekable.\n", filename);
+		Con_Printf("Stream %s not seekable.\n", filename);
 		goto _fail;
 	}
 
-	ogg_info = ov_info(ovFile, 0);
-	if (!ogg_info)
+	ovf_info = ov_info(ovFile, 0);
+	if (!ovf_info)
 	{
-		Con_Printf("Unable to get stream information for %s.\n", filename);
+		Con_Printf("Unable to get stream info for %s.\n", filename);
 		goto _fail;
 	}
 
-	if (ogg_info->channels != 1 && ogg_info->channels != 2)
+	/* FIXME: handle section changes */
+	numstreams = ov_streams(ovFile);
+	if (numstreams != 1)
+	{
+		Con_Printf("More than one (%ld) stream in %s.\n",
+					numstreams, filename);
+		goto _fail;
+	}
+
+	if (ovf_info->channels != 1 && ovf_info->channels != 2)
 	{
 		Con_Printf("Unsupported number of channels %d in %s\n",
-					ogg_info->channels, filename);
+					ovf_info->channels, filename);
 		goto _fail;
 	}
 
-	stream->info.rate = ogg_info->rate;
-	stream->info.channels = ogg_info->channels;
-	stream->info.width = OGG_SAMPLEWIDTH;
+	stream->info.rate = ovf_info->rate;
+	stream->info.channels = ovf_info->channels;
+	stream->info.width = VORBIS_SAMPLEWIDTH;
 
 	return stream;
 _fail:
@@ -129,7 +139,7 @@ _fail:
 	return NULL;
 }
 
-static int S_OGG_CodecReadStream (snd_stream_t *stream, int bytes, void *buffer)
+static int S_VORBIS_CodecReadStream (snd_stream_t *stream, int bytes, void *buffer)
 {
 	int	section;	/* FIXME: handle section changes */
 	int	cnt, res, rem;
@@ -149,8 +159,8 @@ static int S_OGG_CodecReadStream (snd_stream_t *stream, int bytes, void *buffer)
 		res = ov_read( (OggVorbis_File *)stream->priv, ptr, rem,
 #if !defined(VORBIS_USE_TREMOR)
 				host_bigendian,
-				OGG_SAMPLEWIDTH,
-				OGG_SIGNED_DATA,
+				VORBIS_SAMPLEWIDTH,
+				VORBIS_SIGNED_DATA,
 #endif	/* ! VORBIS_USE_TREMOR */
 				&section );
 		if (res <= 0)
@@ -161,17 +171,21 @@ static int S_OGG_CodecReadStream (snd_stream_t *stream, int bytes, void *buffer)
 			break;
 		ptr += res;
 	}
-	return (res >= 0) ? cnt : res;
+
+	if (res < 0)
+		return res;
+
+	return cnt;
 }
 
-static void S_OGG_CodecCloseStream (snd_stream_t *stream)
+static void S_VORBIS_CodecCloseStream (snd_stream_t *stream)
 {
 	ov_clear((OggVorbis_File *)stream->priv);
 	Z_Free(stream->priv);
 	S_CodecUtilClose(&stream);
 }
 
-static int S_OGG_CodecRewindStream (snd_stream_t *stream)
+static int S_VORBIS_CodecRewindStream (snd_stream_t *stream)
 {
 /* for libvorbisfile, the ov_time_seek() position argument
  * is seconds as doubles, whereas for Tremor libvorbisidec
@@ -180,17 +194,17 @@ static int S_OGG_CodecRewindStream (snd_stream_t *stream)
 	return ov_time_seek ((OggVorbis_File *)stream->priv, 0);
 }
 
-snd_codec_t ogg_codec =
+snd_codec_t vorbis_codec =
 {
-	CODECTYPE_OGG,
+	CODECTYPE_VORBIS,
 	true,	/* always available. */
 	"ogg",
-	S_OGG_CodecInitialize,
-	S_OGG_CodecShutdown,
-	S_OGG_CodecOpenStream,
-	S_OGG_CodecReadStream,
-	S_OGG_CodecRewindStream,
-	S_OGG_CodecCloseStream,
+	S_VORBIS_CodecInitialize,
+	S_VORBIS_CodecShutdown,
+	S_VORBIS_CodecOpenStream,
+	S_VORBIS_CodecReadStream,
+	S_VORBIS_CodecRewindStream,
+	S_VORBIS_CodecCloseStream,
 	NULL
 };
 
