@@ -3,7 +3,7 @@
  *
  * Copyright (C) 1999-2005 Id Software, Inc.
  * Copyright (C) 2005 Stuart Dalton <badcdev@gmail.com>
- * Copyright (C) 2010-2011 O.Sezer <sezero@users.sourceforge.net>
+ * Copyright (C) 2010-2012 O.Sezer <sezero@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -203,20 +203,25 @@ snd_stream_t *S_WAV_CodecOpenStream(const char *filename)
 	 * for the FS_*() functions: We will manipulate the
 	 * file by ourselves from now on. */
 	if (!WAV_ReadRIFFHeader(filename, stream->fh.file, &stream->info))
+		goto _fail;
+	if (stream->info.channels != 1 && stream->info.channels != 2)
 	{
-		S_CodecUtilClose(&stream);
-		return NULL;
+		Con_Printf("Unsupported number of channels %d in %s\n",
+					stream->info.channels, filename);
+		goto _fail;
 	}
 
 	stream->fh.start = ftell(stream->fh.file); /* reset to data position */
 	if (stream->fh.start - start + stream->info.size > stream->fh.length)
 	{
 		Con_Printf("%s data size mismatch\n", filename);
-		S_CodecUtilClose(&stream);
-		return NULL;
+		goto _fail;
 	}
 
 	return stream;
+_fail:
+	S_CodecUtilClose(&stream);
+	return NULL;
 }
 
 /*
