@@ -31,34 +31,34 @@ when crossing a water boudnary.
 
 */
 
-cvar_t	scr_ofsx = {"scr_ofsx","0", false};
-cvar_t	scr_ofsy = {"scr_ofsy","0", false};
-cvar_t	scr_ofsz = {"scr_ofsz","0", false};
+cvar_t	scr_ofsx = {"scr_ofsx","0", CVAR_NONE};
+cvar_t	scr_ofsy = {"scr_ofsy","0", CVAR_NONE};
+cvar_t	scr_ofsz = {"scr_ofsz","0", CVAR_NONE};
 
-cvar_t	cl_rollspeed = {"cl_rollspeed", "200"};
-cvar_t	cl_rollangle = {"cl_rollangle", "2.0"};
+cvar_t	cl_rollspeed = {"cl_rollspeed", "200", CVAR_NONE};
+cvar_t	cl_rollangle = {"cl_rollangle", "2.0", CVAR_NONE};
 
-cvar_t	cl_bob = {"cl_bob","0.02", false};
-cvar_t	cl_bobcycle = {"cl_bobcycle","0.6", false};
-cvar_t	cl_bobup = {"cl_bobup","0.5", false};
+cvar_t	cl_bob = {"cl_bob","0.02", CVAR_NONE};
+cvar_t	cl_bobcycle = {"cl_bobcycle","0.6", CVAR_NONE};
+cvar_t	cl_bobup = {"cl_bobup","0.5", CVAR_NONE};
 
-cvar_t	v_kicktime = {"v_kicktime", "0.5", false};
-cvar_t	v_kickroll = {"v_kickroll", "0.6", false};
-cvar_t	v_kickpitch = {"v_kickpitch", "0.6", false};
-cvar_t	v_gunkick = {"v_gunkick", "1"}; //johnfitz
+cvar_t	v_kicktime = {"v_kicktime", "0.5", CVAR_NONE};
+cvar_t	v_kickroll = {"v_kickroll", "0.6", CVAR_NONE};
+cvar_t	v_kickpitch = {"v_kickpitch", "0.6", CVAR_NONE};
+cvar_t	v_gunkick = {"v_gunkick", "1", CVAR_NONE}; //johnfitz
 
-cvar_t	v_iyaw_cycle = {"v_iyaw_cycle", "2", false};
-cvar_t	v_iroll_cycle = {"v_iroll_cycle", "0.5", false};
-cvar_t	v_ipitch_cycle = {"v_ipitch_cycle", "1", false};
-cvar_t	v_iyaw_level = {"v_iyaw_level", "0.3", false};
-cvar_t	v_iroll_level = {"v_iroll_level", "0.1", false};
-cvar_t	v_ipitch_level = {"v_ipitch_level", "0.3", false};
+cvar_t	v_iyaw_cycle = {"v_iyaw_cycle", "2", CVAR_NONE};
+cvar_t	v_iroll_cycle = {"v_iroll_cycle", "0.5", CVAR_NONE};
+cvar_t	v_ipitch_cycle = {"v_ipitch_cycle", "1", CVAR_NONE};
+cvar_t	v_iyaw_level = {"v_iyaw_level", "0.3", CVAR_NONE};
+cvar_t	v_iroll_level = {"v_iroll_level", "0.1", CVAR_NONE};
+cvar_t	v_ipitch_level = {"v_ipitch_level", "0.3", CVAR_NONE};
 
-cvar_t	v_idlescale = {"v_idlescale", "0", false};
+cvar_t	v_idlescale = {"v_idlescale", "0", CVAR_NONE};
 
-cvar_t	crosshair = {"crosshair", "0", true};
+cvar_t	crosshair = {"crosshair", "0", CVAR_ARCHIVE};
 
-cvar_t	gl_cshiftpercent = {"gl_cshiftpercent", "100", false};
+cvar_t	gl_cshiftpercent = {"gl_cshiftpercent", "100", CVAR_NONE};
 
 float	v_dmg_time, v_dmg_roll, v_dmg_pitch;
 
@@ -135,8 +135,8 @@ float V_CalcBob (void)
 //=============================================================================
 
 
-cvar_t	v_centermove = {"v_centermove", "0.15", false};
-cvar_t	v_centerspeed = {"v_centerspeed","500"};
+cvar_t	v_centermove = {"v_centermove", "0.15", CVAR_NONE};
+cvar_t	v_centerspeed = {"v_centerspeed","500", CVAR_NONE};
 
 
 void V_StartPitchDrift (void)
@@ -197,7 +197,8 @@ void V_DriftPitch (void)
 
 		if ( cl.driftmove > v_centermove.value)
 		{
-			V_StartPitchDrift ();
+			if (lookspring.value)
+				V_StartPitchDrift ();
 		}
 		return;
 	}
@@ -887,33 +888,33 @@ void V_Init (void)
 	Cmd_AddCommand ("bf", V_BonusFlash_f);
 	Cmd_AddCommand ("centerview", V_StartPitchDrift);
 
-	Cvar_RegisterVariable (&v_centermove, NULL);
-	Cvar_RegisterVariable (&v_centerspeed, NULL);
+	Cvar_RegisterVariable (&v_centermove);
+	Cvar_RegisterVariable (&v_centerspeed);
 
-	Cvar_RegisterVariable (&v_iyaw_cycle, NULL);
-	Cvar_RegisterVariable (&v_iroll_cycle, NULL);
-	Cvar_RegisterVariable (&v_ipitch_cycle, NULL);
-	Cvar_RegisterVariable (&v_iyaw_level, NULL);
-	Cvar_RegisterVariable (&v_iroll_level, NULL);
-	Cvar_RegisterVariable (&v_ipitch_level, NULL);
+	Cvar_RegisterVariable (&v_iyaw_cycle);
+	Cvar_RegisterVariable (&v_iroll_cycle);
+	Cvar_RegisterVariable (&v_ipitch_cycle);
+	Cvar_RegisterVariable (&v_iyaw_level);
+	Cvar_RegisterVariable (&v_iroll_level);
+	Cvar_RegisterVariable (&v_ipitch_level);
 
-	Cvar_RegisterVariable (&v_idlescale, NULL);
-	Cvar_RegisterVariable (&crosshair, NULL);
-	Cvar_RegisterVariable (&gl_cshiftpercent, NULL);
+	Cvar_RegisterVariable (&v_idlescale);
+	Cvar_RegisterVariable (&crosshair);
+	Cvar_RegisterVariable (&gl_cshiftpercent);
 
-	Cvar_RegisterVariable (&scr_ofsx, NULL);
-	Cvar_RegisterVariable (&scr_ofsy, NULL);
-	Cvar_RegisterVariable (&scr_ofsz, NULL);
-	Cvar_RegisterVariable (&cl_rollspeed, NULL);
-	Cvar_RegisterVariable (&cl_rollangle, NULL);
-	Cvar_RegisterVariable (&cl_bob, NULL);
-	Cvar_RegisterVariable (&cl_bobcycle, NULL);
-	Cvar_RegisterVariable (&cl_bobup, NULL);
+	Cvar_RegisterVariable (&scr_ofsx);
+	Cvar_RegisterVariable (&scr_ofsy);
+	Cvar_RegisterVariable (&scr_ofsz);
+	Cvar_RegisterVariable (&cl_rollspeed);
+	Cvar_RegisterVariable (&cl_rollangle);
+	Cvar_RegisterVariable (&cl_bob);
+	Cvar_RegisterVariable (&cl_bobcycle);
+	Cvar_RegisterVariable (&cl_bobup);
 
-	Cvar_RegisterVariable (&v_kicktime, NULL);
-	Cvar_RegisterVariable (&v_kickroll, NULL);
-	Cvar_RegisterVariable (&v_kickpitch, NULL);
-	Cvar_RegisterVariable (&v_gunkick, NULL); //johnfitz
+	Cvar_RegisterVariable (&v_kicktime);
+	Cvar_RegisterVariable (&v_kickroll);
+	Cvar_RegisterVariable (&v_kickpitch);
+	Cvar_RegisterVariable (&v_gunkick); //johnfitz
 }
 
 
