@@ -62,7 +62,7 @@ all big things are allocated on the hunk.
 ==============================================================================
 */
 
-memzone_t	*mainzone;
+static memzone_t	*mainzone;
 
 
 /*
@@ -246,8 +246,9 @@ void *Z_Realloc(void *ptr, int size)
 
 char *Z_Strdup (const char *s)
 {
-	char *ptr = (char *) Z_Malloc (strlen(s) + 1);
-	strcpy (ptr, s);
+	size_t sz = strlen(s) + 1;
+	char *ptr = (char *) Z_Malloc (sz);
+	memcpy (ptr, s, sz);
 	return ptr;
 }
 
@@ -575,8 +576,9 @@ void *Hunk_TempAlloc (int size)
 
 char *Hunk_Strdup (const char *s, const char *name)
 {
-	char *ptr = (char *) Hunk_AllocName (strlen(s) + 1, name);
-	strcpy (ptr, s);
+	size_t sz = strlen(s) + 1;
+	char *ptr = (char *) Hunk_AllocName (sz, name);
+	memcpy (ptr, s, sz);
 	return ptr;
 }
 
@@ -825,16 +827,6 @@ void Cache_Report (void)
 	Con_DPrintf ("%4.1f megabyte data cache\n", (hunk_size - hunk_high_used - hunk_low_used) / (float)(1024*1024) );
 }
 
-/*
-============
-Cache_Compact
-
-============
-*/
-void Cache_Compact (void)
-{
-}
-
 /*
 ============
 Cache_Init
@@ -874,10 +866,10 @@ void Cache_Free (cache_user_t *c, qboolean freetextures) //johnfitz -- added sec
 	Cache_UnlinkLRU (cs);
 
 	//johnfitz -- if a model becomes uncached, free the gltextures.  This only works
-	//becuase the cache_user_t is the last component of the model_t struct.  Should
+	//becuase the cache_user_t is the last component of the qmodel_t struct.  Should
 	//fail harmlessly if *c is actually part of an sfx_t struct.  I FEEL DIRTY
 	if (freetextures)
-		TexMgr_FreeTexturesForOwner ((model_t *)(c + 1) - 1);
+		TexMgr_FreeTexturesForOwner ((qmodel_t *)(c + 1) - 1);
 }
 
 
